# edzed

A library for building small automated systems.

The package contains:

- classes for creating combinational and sequential blocks
- methods for building a circuit by connecting the blocks
- a simple event-driven zero-delay digital circuit simulator

## Documentation

Please see the [online documentation](https://edzed.readthedocs.io/en/latest/) for more information.
